@@ -41,10 +41,10 @@ Configuration file for Home Site Maker
 */
 
 
-$VERSION="homesitemaker-v0.4.6";                     // [STOP] Only for upgrading purporses
+$VERSION="homesitemaker-v0.4.7";                     // [STOP] Only for upgrading purporses
 $TITLE="Homesite Maker";                             // [EDIT] The title of your website
 $DESCRIPTION="The Homesite Maker project home page"; // [EDIT] A brief description of your website
-$URL="http://homesitemaker-devel-local.org";         // [REQUIRED] The URL used to serve your site
+$URL="http://yoursite.org";                          // [REQUIRED] The URL used to serve your site
 
 $SKIN="white_clouds"; // [OPT] Available skins are rainbow, aqua, simple, black-simple, black-grey and white_clouds
 $ICONS="white_clouds";// [OPT] Available icon-set is white_clouds
