@@ -25,10 +25,7 @@ Marcos Martinez Jimenez
 marcos@assl-site.net
 http://homesitemaker.no-ip.org
 Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
-*/
 
-
-/*
 Data Base Write Agent (DBWA) is an intermediate layer which provide access
 to the homesite database to perform write, delete, or update queries.
 */
@@ -55,6 +52,7 @@ if (!get_magic_quotes_gpc())
           }
 
 if (isset($_POST['text_type'])) {$text_type=($_POST['text_type']);} else {$text_type="text";}
+if (isset($_POST['typed_secret_code'])) {$typed_secret_code=($_POST['typed_secret_code']);} else {$typed_secret_code="text";}
 if ($text_type=="text"){$body_text=nl2br($body_text);}
 
 if (isset($_POST['num_photos'])) {$num_photos=$_POST['num_photos'];}
@@ -429,15 +427,21 @@ foreach ($id_photo_list as $value)
 return 0;
 }
 
-function dbwa_put_comment ($id_info, $id_author, $id_comment, $posted, $title, $body_text, $text_type){
+function dbwa_put_comment ($id_info, $id_author, $id_comment, $posted, $title, $body_text, $text_type, $typed_secret_code){
 include ("config_site.php");
 include ("db_connect.php");
-
+include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
+session_start();
+$secret_code = $_SESSION["captcha-session"];
 // if father_comment field is 0 the comment is a new comment.
 // if father_comment field is != 0 then, the comment is a answer to comment.
 $father_comment=$id_comment;
 
-mysql_query ("INSERT INTO comment (id_info,id_author,father_comment,posted,title,body_text,text_type) values ('$id_info','$id_author', '$father_comment' ,'$posted', '$title','$body_text','$text_type')");
+if ( strcasecmp ( $secret_code, $typed_secret_code) == 0 )
+   {
+   mysql_query ("INSERT INTO comment (id_info,id_author,father_comment,posted,title,body_text,text_type) 
+                             values ('$id_info','$id_author', '$father_comment' ,'$posted', '$title','$body_text','$text_type')");
+   } else echo "<div class=\"alert1b\" align=\"center\">$TEXT021</div>";
 
 return 0;
 }
@@ -922,7 +926,7 @@ if(isset($dbwa) && $dbwa!="NULL")
     if ($dbwa=="dbwa_add_user") $dbwa ($new_nick, $password, $password_check, $email, $real_name, $level);
     if ($dbwa=="dbwa_delete_user") $dbwa ($id_user);
     if ($dbwa=="dbwa_diary") $dbwa ($top_tab, $section_type, $event_title, $event_type, $event_place, $description, $day, $year, $month, $hour, $minutes); 
-    if ($dbwa=="dbwa_put_comment") $dbwa ($id_info, $id_session['id_user'], $id_comment, $posted, $title, $body_text,$text_type);
+    if ($dbwa=="dbwa_put_comment") $dbwa ($id_info, $id_session['id_user'], $id_comment, $posted, $title, $body_text,$text_type,$typed_secret_code);
     if ($dbwa=="dbwa_add_album") $valid_album_form=$dbwa ($title, $description, $posted, $id_session['id_user'],"TAB_$top_tab$section_type",$allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list); 
     if ($dbwa=="dbwa_edit_album") $dbwa ($id_album, $title, $description, $posted, "TAB_$top_tab$section_type",$allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list); 
     if ($dbwa=="dbwa_add_photo_album") $dbwa ($id_album,$id_session['id_user'], $description,$posted);
@@ -932,7 +936,7 @@ if(isset($dbwa) && $dbwa!="NULL")
     } else if ($dbwa=="dbwa_add_unprivileged_user" || $dbwa=="dbwa_put_comment" || $dbwa=="dbwa_add_info" || $dbwa=="dbwa_edit_info" || $dbwa=="dbwa_add_photo_album")
               {
               if ($dbwa=="dbwa_add_unprivileged_user") $dbwa ($new_nick, $password, $password_check, $email, $real_name);
-              if ($dbwa=="dbwa_put_comment") $dbwa ($id_info, 0, $id_comment, $posted, $title, $body_text,$text_type);
+              if ($dbwa=="dbwa_put_comment") $dbwa ($id_info, 0, $id_comment, $posted, $title, $body_text,$text_type,$typed_secret_code);
               if ($dbwa=="dbwa_edit_info") $dbwa ($id_info,$id_photo, $headline, $body_text, $text_type, $edited,'anonymous',$num_photos, $task, $choice);
               if ($dbwa=="dbwa_add_info") $id_info=$dbwa ($id_photo, $headline, $body_text, $text_type, $posted, 0,'anonymous',"TAB_$top_tab$section_type",$choice); 
              if ($dbwa=="dbwa_add_photo_album") $dbwa ($id_album,$id_session['id_user'], $description,$posted);
