@@ -1010,19 +1010,24 @@ if ($task=="put_comment" || $task=="answer_comment")
         "<option value=\"html\">$TEXT047</option>".
         "</SELECT></td></tr>".
         "<tr><td class=\"text1\" colspan=4>$TEXT017<br><br></td></tr>".
+        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT059".
+        "<img src=\"includes/create_captcha.php\"></td></tr>".
+        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT060".
+        "<input type=text name=\"typed_secret_code\" size=4></input></td></tr>".
         "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
         "&nbsp;<input type=\"submit\" value=\"$TEXT001\"></input><br></td></tr>".
         "</form>";
+
    }
 
 if ($task=="put_commentGUI" || $task=="answer_commentGUI")
    {
    if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="ERROR";}
    if (isset($_GET['id_comment'])) {$id_comment=$_GET['id_comment'];} else {$id_comment=0;}
-   if ($task=="put_comment")
+   if ($task=="put_commentGUI")
       {
       $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
-      } else if ($task=="answer_comment") {$info_query=mysql_query("SELECT * FROM comment WHERE id_comment='$id_comment'", $db);}
+      } else if ($task=="answer_commentGUI") {$info_query=mysql_query("SELECT * FROM comment WHERE id_comment='$id_comment'", $db);}
    $info_result=mysql_fetch_array ($info_query);
    echo "<form enctype=\"multipart/form-data\" method=\"post\"".
         " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
@@ -1062,14 +1067,19 @@ if ($task=="put_commentGUI" || $task=="answer_commentGUI")
    $oFCKeditor->Height = '200' ;
    $oFCKeditor->Value = "$TEXT057";
    $oFCKeditor->Create() ;
+
    echo "</td></tr><tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
         "<option value=\"html\">$TEXT047</option>".
         "</SELECT></td></tr>".
         "<tr><td class=\"text1\" colspan=4>$TEXT017<br><br></td></tr>".
+        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT059".
+        "<img src=\"includes/create_captcha.php\"></td></tr>".
+        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT060".
+        "<input type=text name=\"typed_secret_code\" size=4></input></td></tr>".
         "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
         "&nbsp;<input type=\"submit\" value=\"$TEXT001\"></input><br></td></tr>".
         "</form>";
-   }
+  }
 
 if ($task=="rss_feeds")
    {
